@@ -4,6 +4,7 @@ var app = new Vue({
   el: '#vuejs',
   data: {
     source: null,
+    has_state: false,
     state: { folders: [] },
     selected_folder: null,
     pending_uploads: [],
@@ -26,13 +27,19 @@ var app = new Vue({
       return this.selected_folder ? this.selected_folder.path : '-'
     }
   },
-  mounted: function () {
+  watch: {
+    selected_folder (new_folder) {
+      this.reset()
+    }
+  },
+  mounted () {
     const self = this
     this.source = new EventSource('/uploads')
     this.source.onmessage = function (event) {
       const json_data = JSON.parse(event.data)
 
       self.state = json_data.state
+      self.has_state = true
       if (!self.selected_folder && self.state.folders.length > 0) {
         self.selected_folder = self.state.folders[0]
       }
@@ -51,6 +58,15 @@ var app = new Vue({
     }
   },
   methods: {
+    reset () {
+      this.pending_uploads = []
+      this.current_uploads = []
+      this.finished_uploads = []
+      this.error_uploads = []
+      this.progresses = []
+      this.finished_count = 0
+      this.skipped_count = 0
+    },
     retryAllFailed () {
       fetch('/retries?ids=' + this.error_uploads.reduce((acc, value) => acc + value.id.toString() + ',', ''))
     }
